# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# noarch, but to avoid *.list files interfering with signature test
%global debug_package %{nil}

# Store keys in a temp directory
%global gnupghome %(mktemp --directory)

Name:		perl-Test-Assert
Version:	0.0504
Release:	39.%{__distinit}%{__distvers}
Summary:	Assertion methods for those who like JUnit
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Assert
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Assert-%{version}.tar.gz
Source1:	C0B10A5B.pub
Patch0:		Test-Assert-0.0504-Critic.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gnupg2
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Module::Build)
# Module Runtime
BuildRequires:	perl(constant)
BuildRequires:	perl(constant::boolean) >= 0.02
BuildRequires:	perl(Exception::Base) >= 0.21
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol::Util) >= 0.0202
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Carp)
BuildRequires:	perl(Class::Inspector)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(parent)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(Test::Unit::Lite) >= 0.11
# Release Tests
BuildRequires:	patch
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(Test::Signature)
BuildRequires:	perl(Test::Spelling), hunspell-en
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This class provides a set of assertion methods useful for writing tests.
The API is based on JUnit4 and Test::Unit and the methods die on failure.

%prep
%setup -q -n Test-Assert-%{version}

# Drop exec bits and avoid doc-file dependencies
chmod -c -x eg/*

# Import upstream's GPG key so we don't need to fetch it from a keyserver
# when running the signature test
export GNUPGHOME=%{gnupghome}
gpg2 --import %{SOURCE1}

%build
perl Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%{_fixperms} -c %{buildroot}

%check
# === MAIN TEST SUITE === #

./Build test

# ===  RELEASE TESTS  === #
export GNUPGHOME=%{gnupghome}
RELEASE_TESTS="$(echo xt/*.t)"

# Don't run the copyright test as it will fail after the year of module release
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/copyright.t||')"

# Don't run the spelling test yet as we need to add extra stopwords
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/pod_spell.t||')"

# Don't run the perlcritic test yet as we need to patch the code
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/perlcritic.t||')"

# Signature test would fail on recent distros due to presence of MYMETA.*
[ -f MYMETA.yml ] && mv MYMETA.yml ..
[ -f MYMETA.json ] && mv MYMETA.json ..

RELEASE_TESTING=1 ./Build test --test_files "$RELEASE_TESTS"

# Put any MYMETA.* files back where they were
[ -f ../MYMETA.yml ] && mv ../MYMETA.yml .
[ -f ../MYMETA.json ] && mv ../MYMETA.json .

# Patch the code to turn off one check before running the perlcritic test
patch -p0 < %{P:0}
./Build test --test_files xt/perlcritic.t
patch -p0 -R < %{P:0}

# Fix the POD Spell test and run it
mv xt/pod_spellrc xt/pod_spellrc.orig
(
	cat xt/pod_spellrc.orig
	echo "'fail'"
	echo "JUnit4"
	echo "value1"
	echo "value2"
) > xt/pod_spellrc
./Build test --test_files xt/pod_spell.t
mv xt/pod_spellrc.orig xt/pod_spellrc

%clean
rm -rf %{buildroot} %{gnupghome}

%files
%license LICENSE
%doc Changes README eg/
%{perl_vendorlib}/Exception/
%{perl_vendorlib}/Test/
%{_mandir}/man3/Exception::Assertion.3*
%{_mandir}/man3/Test::Assert.3*

%changelog
* Wed Mar 29 2023 Paul Howarth <paul@city-fan.org> - 0.0504-39
- Use SPDX-format license tag

* Fri Mar 11 2022 Paul Howarth <paul@city-fan.org> - 0.0504-36
- Use %%license unconditionally

* Sun Jun  9 2019 Paul Howarth <paul@city-fan.org> - 0.0504-26
- Perl 5.30 rebuild

* Wed Apr 11 2018 Paul Howarth <paul@city-fan.org> - 0.0504-22
- Use mktemp to create GNUPGHOME, simplifying build process
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Wed Apr 12 2017 Paul Howarth <paul@city-fan.org> - 0.0504-19
- Use an ephemeral temporary directory for GPG key storage

* Wed Apr  5 2017 Paul Howarth <paul@city-fan.org> - 0.0504-18
- Use gnupg2 rather than gnupg
- Drop support for EOL distributions prior to F-13:
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Don't need any workaround for Test::More < 0.88
  - Speller is always hunspell now

* Wed Sep 28 2016 Paul Howarth <paul@city-fan.org> - 0.0504-16
- Fix FTBFS when perl is not in the minimal buildroot
- Classify buildreqs by usage

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 0.0504-12
- Use %%license where possible

* Thu Jul 10 2014 Paul Howarth <paul@city-fan.org> - 0.0504-11
- Drop %%defattr, redundant since rpm 4.4
- Update upstream signing key
- Update critic patch to work if
  Perl::Critic::Policy::ValuesAndExpressions::ProhibitNullStatements is
  installed (part of Perl-Critic-Pulp distribution) (#1118374)

* Thu Jul 25 2013 Paul Howarth <paul@city-fan.org> - 0.0504-7
- Perl 5.18 rebuild

* Fri Jun 21 2013 Paul Howarth <paul@city-fan.org> - 0.0504-6
- Tweak the perlcritic test, which has discovered something to moan about

* Sun Jul 15 2012 Paul Howarth <paul@city-fan.org> - 0.0504-4
- BR: perl(Carp), perl(Cwd), perl(File::Spec) and perl(Test::Builder)
- Drop non-dual-lived Perl core buildreqs
- Specify version requirements for Test::Pod and Test::Pod::Coverage

* Fri Mar  9 2012 Paul Howarth <paul@city-fan.org> - 0.0504-3
- Use Module::Build flow
- Don't need to remove empty directories from buildroot
- Require at least version 0.02 of constant::boolean
- Don't make permanent changes to tests in %%check
- BR: Perl core modules that might be dual-lived
- Drop compatibility with distributions prior to FC-3:
  - Perl::Critic always available
  - Don't need to define %%{perl_vendorlib}
  - Never need to BR: aspell-en-gb

* Mon Jul  4 2011 Paul Howarth <paul@city-fan.org> - 0.0504-2
- Rebuild for perl 5.14.1 in Rawhide
- Work around signature test failing on recent distributions due to presence
  of MYMETA.yml
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May  6 2011 Paul Howarth <paul@city-fan.org> - 0.0504-1
- Import from Fedora
- Update to 0.0504:
  - Fixed error message for assert_deep_equals
  - Uses Symbol::Util as exported; all exported symbols can be removed with
    "no Test::Assert" statement
  - Minor refactoring of "assert_deep_equals" method and its private methods
  - Require Symbol::Util ≥ 0.0202 and constant::boolean ≥ 0.02
  - Build requires Class::Inspector
  - The ":assert" tag also imports the "ASSERT" constant

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0501-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 22 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.0501-6
- Rebuild to fix problems with vendorarch/lib (#661697)

* Thu May 06 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.0501-5
- Mass rebuild with perl-5.12.0

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 0.0501-4
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0501-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0501-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jan 29 2009 Allisson Azevedo <allisson@gmail.com> - 0.0501-1
- Initial rpm release
